@@ -14,9 +14,9 @@ def get_ssm_path(project, application, stage, key=None, prefix=None):
 
 ###--------------------------------------------------------------------------------------------
 
-def load_ssm_path(parameters, path, parameter_type, prefix=None, decrypt=False, recurisve=True):
+def load_ssm_path(parameters, path, parameter_type, prefix=None, decrypt=False):
     p = ssm.get_paginator('get_parameters_by_path')
-    paginator = p.paginate(Path=path, Recursive=recurisve, WithDecryption=decrypt, ParameterFilters=[{'Key': 'Type','Values': parameter_type}]).build_full_result()
+    paginator = p.paginate(Path=path, Recursive=True, WithDecryption=decrypt, ParameterFilters=[{'Key': 'Type', 'Values': parameter_type}]).build_full_result()
     for parameter in paginator['Parameters']:
         key = parameter['Name'][len(path)+1:]
         if key in parameters:
