@@ -28,7 +28,7 @@ from .dict_utils import *
 
 @click.group(context_settings=DEFAULT_CLICK_CONTEXT)
 def cli():
-    """DSO CLI"""
+    """Mable DSO CLI"""
     pass
 
 ###--------------------------------------------------------------------------------------------
@@ -112,7 +112,7 @@ def version():
     """
     Display version details.
     """
-    click.echo(f"DSO CLI: {__version__}\nPython: {platform.sys.version}")
+    click.echo(f"Mable DSO CLI: {__version__}\nPython: {platform.sys.version}")
 
 
 ###--------------------------------------------------------------------------------------------
@@ -199,6 +199,7 @@ def add_parameter(key, key_option, value, value_option, stage, input, format, ve
 @command_doc(CLI_COMMANDS_HELP['parameter']['list'])
 @click.option('-s', '--stage', metavar='<name>[/<number>]', default='default', help=f"{CLI_PARAMETERS_HELP['common']['stage']}")
 @click.option('-u','--uninherited', 'uninherited', is_flag=True, default=False, help=f"{CLI_PARAMETERS_HELP['parameter']['uninherited']}")
+@click.option('--filter', required=False, metavar='<regex>', help=f"{CLI_PARAMETERS_HELP['common']['filter']}")
 @click.option('-a', '--query-all', required=False, is_flag=True, default=False, show_default=True, help=f"{CLI_PARAMETERS_HELP['common']['query_all']}")
 @click.option('-q', '--query', metavar='<jmespath>', required=False, help=f"{CLI_PARAMETERS_HELP['common']['query']}")
 @click.option('-f', '--format', required=False, type=click.Choice(['json', 'yaml', 'csv', 'raw', 'shell']), default='json', show_default=True, help=f"{CLI_PARAMETERS_HELP['common']['format']}")
@@ -207,13 +208,18 @@ def add_parameter(key, key_option, value, value_option, stage, input, format, ve
 @click.option('--project-scope', required=False, is_flag=True, help=f"{CLI_PARAMETERS_HELP['common']['project_scope']}")
 @click.option('--config-override', 'config_override', metavar='<key>=<value>,...', required=False, help=f"{CLI_PARAMETERS_HELP['common']['config']}")
 @click.option('-w','--working-dir', metavar='<path>', type=click.Path(exists=True, file_okay=False), required=False, help=f"{CLI_PARAMETERS_HELP['common']['working_dir']}")
-def list_parameter(stage, uninherited, query_all, query, format, verbosity, global_scope, project_scope, config_override, working_dir):
+def list_parameter(stage, uninherited, filter, query_all, query, format, verbosity, global_scope, project_scope, config_override, working_dir):
 
     def validate_command_usage():
         nonlocal stage, query
         stage = Stages.normalize(stage)
         validate_not_all_provided([global_scope, project_scope], ["'--global-scope'", "'--project-scope'"])
         query = validate_query_argument(query, query_all, '{Parameters: Parameters[*].{Key: Key, Value: Value}}')
+        if filter:
+            try:
+                re.compile(filter)
+            except Exception as e:
+                raise DSOException(CLI_MESSAGES['InvalidFilter'].format(e.msg))
 
     try:
         Logger.set_verbosity(verbosity)
@@ -221,7 +227,7 @@ def list_parameter(stage, uninherited, query_all, query, format, verbosity, glob
         Configs.load(working_dir if working_dir else os.getcwd(),
                         'global' if global_scope else 'project' if project_scope else 'application',
                         config_override)
-        result = Parameters.list(stage, uninherited)
+        result = Parameters.list(stage, uninherited, filter)
         output = format_data(result, query, format)
         if output: Pager.page(output)
 
@@ -431,6 +437,7 @@ def add_secret(key, key_option, stage, input, format, verbosity, global_scope, p
 @click.option('-s', '--stage', metavar='<name>[/<number>]', default='default', help=f"{CLI_PARAMETERS_HELP['common']['stage']}")
 @click.option('-d', '--decrypt', required=False, is_flag=True, default=False, show_default=True, help=f"{CLI_PARAMETERS_HELP['parameter']['query_values']}")
 @click.option('-u','--uninherited', 'uninherited', is_flag=True, default=False, help=f"{CLI_PARAMETERS_HELP['secret']['uninherited']}")
+@click.option('--filter', required=False, metavar='<regex>', help=f"{CLI_PARAMETERS_HELP['common']['filter']}")
 @click.option('-a', '--query-all', required=False, is_flag=True, default=False, show_default=True, help=f"{CLI_PARAMETERS_HELP['common']['query_all']}")
 @click.option('-q', '--query', metavar='<jmespath>', required=False, help=f"{CLI_PARAMETERS_HELP['common']['query']}")
 @click.option('-f', '--format', required=False, type=click.Choice(['json', 'yaml', 'raw', 'csv', 'shell']), default='json', show_default=True, help=f"{CLI_PARAMETERS_HELP['common']['format']}")
@@ -439,13 +446,18 @@ def add_secret(key, key_option, stage, input, format, verbosity, global_scope, p
 @click.option('--project-scope', required=False, is_flag=True, help=f"{CLI_PARAMETERS_HELP['common']['project_scope']}")
 @click.option('--config-override', 'config_override', metavar='<key>=<value>,...', required=False, help=f"{CLI_PARAMETERS_HELP['common']['config']}")
 @click.option('-w','--working-dir', metavar='<path>', type=click.Path(exists=True, file_okay=False), required=False, help=f"{CLI_PARAMETERS_HELP['common']['working_dir']}")
-def list_secret(stage, uninherited, decrypt, query_all, query, format, verbosity, global_scope, project_scope, config_override, working_dir):
+def list_secret(stage, uninherited, decrypt, filter, query_all, query, format, verbosity, global_scope, project_scope, config_override, working_dir):
 
     def validate_command_usage():
         nonlocal stage, query
         stage = Stages.normalize(stage)
         query = validate_query_argument(query, query_all, '{Secrets: Secrets[*].{Key: Key, Value: Value}}')
         validate_not_all_provided([global_scope, project_scope], ["'--global-scope'", "'--project-scope'"])
+        if filter:
+            try:
+                re.compile(filter)
+            except Exception as e:
+                raise DSOException(CLI_MESSAGES['InvalidFilter'].format(e.msg))
 
     try:
         Logger.set_verbosity(verbosity)
@@ -453,7 +465,7 @@ def list_secret(stage, uninherited, decrypt, query_all, query, format, verbosity
         Configs.load(working_dir if working_dir else os.getcwd(),
                         'global' if global_scope else 'project' if project_scope else 'application',
                         config_override)
-        result = Secrets.list(stage, uninherited, decrypt)
+        result = Secrets.list(stage, uninherited, decrypt, filter)
         output = format_data(result, query, format)
         if output: Pager.page(output)
 
@@ -588,6 +600,7 @@ def delete_secret(key, key_option, input, format, stage, verbosity, global_scope
 @command_doc(CLI_COMMANDS_HELP['template']['list'])
 @click.option('-u','--uninherited', 'uninherited', is_flag=True, default=False, help=f"{CLI_PARAMETERS_HELP['template']['uninherited']}")
 @click.option('-s', '--stage', metavar='<name>[/<number>]', default='default', help=f"{CLI_PARAMETERS_HELP['common']['stage']}")
+@click.option('--filter', required=False, metavar='<regex>', help=f"{CLI_PARAMETERS_HELP['common']['filter']}")
 @click.option('-a', '--query-all', required=False, is_flag=True, default=False, show_default=True, help=f"{CLI_PARAMETERS_HELP['common']['query_all']}")
 @click.option('-q', '--query', metavar='<jmespath>', required=False, help=f"{CLI_PARAMETERS_HELP['common']['query']}")
 @click.option('-f', '--format', required=False, type=click.Choice(['json', 'yaml', 'csv', 'raw']), default='json', show_default=True, help=f"{CLI_PARAMETERS_HELP['common']['format']}")
@@ -596,13 +609,18 @@ def delete_secret(key, key_option, input, format, stage, verbosity, global_scope
 @click.option('--project-scope', required=False, is_flag=True, help=f"{CLI_PARAMETERS_HELP['common']['project_scope']}")
 @click.option('--config-override', 'config_override', metavar='<key>=<value>,...', required=False, help=f"{CLI_PARAMETERS_HELP['common']['config']}")
 @click.option('-w','--working-dir', metavar='<path>', type=click.Path(exists=True, file_okay=False), required=False, help=f"{CLI_PARAMETERS_HELP['common']['working_dir']}")
-def list_template(uninherited, stage, query_all, query, format, verbosity, global_scope, project_scope, config_override, working_dir):
+def list_template(uninherited, stage, filter, query_all, query, format, verbosity, global_scope, project_scope, config_override, working_dir):
 
     def validate_command_usage():
         nonlocal stage, query
         stage = Stages.normalize(stage)
         query = validate_query_argument(query, query_all, '{Templates: Templates[*].{Key: Key, RenderTo: RenderTo}}')
         validate_not_all_provided([global_scope, project_scope], ["'--global-scope'", "'--project-scope'"])
+        if filter:
+            try:
+                re.compile(filter)
+            except Exception as e:
+                raise DSOException(CLI_MESSAGES['InvalidFilter'].format(e.msg))
 
     try:
         Logger.set_verbosity(verbosity)
@@ -610,7 +628,7 @@ def list_template(uninherited, stage, query_all, query, format, verbosity, globa
         Configs.load(working_dir if working_dir else os.getcwd(),
                         'global' if global_scope else 'project' if project_scope else 'application',
                         config_override)
-        result = Templates.list(stage, uninherited)
+        result = Templates.list(stage, uninherited, filter)
         output = format_data(result, query, format)
         if output: Pager.page(output)
     except DSOException as e:
@@ -870,18 +888,23 @@ def delete_template(key, key_option, stage, input, format, verbosity, global_sco
 @template.command('render', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['template']['render']}")
 @command_doc(CLI_COMMANDS_HELP['template']['render'])
 @click.option('-s', '--stage', metavar='<name>[/<number>]', default='default', help=f"{CLI_PARAMETERS_HELP['common']['stage']}")
-@click.option('-l', '--limit', required=False, default='', help=f"{CLI_PARAMETERS_HELP['template']['limit']}")
+@click.option('--filter', required=False, metavar='<regex>', help=f"{CLI_PARAMETERS_HELP['common']['filter']}")
 @click.option('-b', '--verbosity', metavar='<number>', required=False, type=RangeParamType(click.INT, minimum=0, maximum=5), default='2', show_default=True, help=f"{CLI_PARAMETERS_HELP['common']['verbosity']}")
 @click.option('--global-scope', required=False, is_flag=True, help=f"{CLI_PARAMETERS_HELP['common']['global_scope']}")
 @click.option('--project-scope', required=False, is_flag=True, help=f"{CLI_PARAMETERS_HELP['common']['project_scope']}")
 @click.option('--config-override', 'config_override', metavar='<key>=<value>,...', required=False, help=f"{CLI_PARAMETERS_HELP['common']['config']}")
 @click.option('-w','--working-dir', metavar='<path>', type=click.Path(exists=True, file_okay=False), required=False, help=f"{CLI_PARAMETERS_HELP['common']['working_dir']}")
-def render_template(stage, limit, verbosity, global_scope, project_scope, config_override, working_dir):
+def render_template(stage, filter, verbosity, global_scope, project_scope, config_override, working_dir):
 
     def validate_command_usage():
         nonlocal stage
         stage = Stages.normalize(stage)
         validate_not_all_provided([global_scope, project_scope], ["'--global-scope'", "'--project-scope'"])
+        if filter:
+            try:
+                re.compile(filter)
+            except Exception as e:
+                raise DSOException(CLI_MESSAGES['InvalidFilter'].format(e.msg))
 
     try:
         Logger.set_verbosity(verbosity)
@@ -890,7 +913,7 @@ def render_template(stage, limit, verbosity, global_scope, project_scope, config
                         'global' if global_scope else 'project' if project_scope else 'application',
                         config_override)
 
-        success = Templates.render(stage, limit)
+        success = Templates.render(stage, filter)
         result = {'Success': success, 'Failure': []}
         output = format_data(result, '', 'json') ### FIXME: use a global output format setting
         if output: Pager.page(output)
