@@ -136,6 +136,7 @@ CLI_PARAMETERS_HELP = {
         'query_all': "Include all the available fields in the ouput.",
         'global_scope': "Use the global context.",
         'project_scope': "Use the project context.",
+        'filter': "Use a regex pattern to filter result by the provider.",
 
     },
     'parameter': {
@@ -201,4 +202,5 @@ CLI_MESSAGES = {
     'RenderPathNotReleative': "Render path '{0}' is not releative to the application root directory.",
     # 'InvalidRenderPath': "'{0}' is not a valid render path.",
     'InvalidRenderPathExistingDir': "'{0}' is not a valid render path because it is an existing directory.",
+    'InvalidFilter': "Invalid regex pattern for filter: {0}",
 }
