@@ -1,6 +1,9 @@
+import sys
+import os
 import click
 from .logger import Logger
 from .cli_constants import *
+import tempfile
 
 class MuOption(click.Option):
     def __init__(self, *args, **kwargs):
@@ -104,3 +107,14 @@ def command_doc(value):
         func.__doc__ = value
         return func
     return _doc
+
+
+def check_file_path(ctx, self, value):
+    if value == '-':
+        with tempfile.NamedTemporaryFile("w", delete=False) as f:
+            f.write(sys.stdin.read())
+            value = f.name
+    else:
+        if not os.path.exists(value):
+            raise click.BadParameter(f"'{value}' does not exist.")
+    return value
\ No newline at end of file
