@@ -137,7 +137,7 @@ class LoggerClass():
         if LABEL_LOG_LEVELS: log_format += ' [%(levelname)-8s]'
         log_format += ' %(message)s'
         logging.basicConfig(format=log_format, datefmt='%Y-%m-%d %H:%M:%S', level=logger_verbosity_map[str(log_level)])
-        self.LOG = logging.getLogger('dsocli')
+        self.LOG = logging.getLogger('mabledsocli')
 
     def set_verbosity(self, log_level):
         self.__level = log_level
