@@ -4,12 +4,12 @@ import yaml
 import json
 import pathlib
 import numbers
-from dsocli.logger import Logger
-from dsocli.config import Configs
-from dsocli.parameters import ParameterProvider
-from dsocli.stages import Stages
-from dsocli.constants import *
-from dsocli.utils import *
+from mabledsocli.logger import Logger
+from mabledsocli.config import Configs
+from mabledsocli.parameters import ParameterProvider
+from mabledsocli.stages import Stages
+from mabledsocli.constants import *
+from mabledsocli.utils import *
 
 defaults = {
     'format': 'yaml',
@@ -183,24 +183,6 @@ class LocalParameterProvider(ParameterProvider):
                     path = self.__get_param_file_path_from_key('', key)
         return path
 
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
-
-    def get_key_validator(self):
-
-        allowGroups = Configs.parameter_spec('allowGroups')
-        if allowGroups is None:
-            Logger.debug(f"'allowGroups' is not set for the parameter provider, defaulted to '{defaults['allowGroups']}'.")
-            allowGroups = defaults['allowGroups']
-
-        if allowGroups:
-            return r"^([a-zA-Z][a-zA-Z0-9]*/)?([a-zA-Z][a-zA-Z0-9_.-]*)$"
-        else:
-            return r"^([a-zA-Z][a-zA-Z0-9_.-]*)$"
-
-
-
-
 ###--------------------------------------------------------------------------------------------
 
     def add(self, context, key, value):
