@@ -1,15 +1,15 @@
 import re
 import boto3
-from dsocli.exceptions import DSOException
-from dsocli.logger import Logger
-from dsocli.config import Configs
-from dsocli.providers import Providers
-from dsocli.secrets import SecretProvider
-from dsocli.stages import Stages
-from dsocli.constants import *
-from dsocli.dict_utils import set_dict_value
-from dsocli.contexts import Contexts
-from dsocli.aws_utils import *
+from mabledsocli.exceptions import DSOException
+from mabledsocli.logger import Logger
+from mabledsocli.config import Configs
+from mabledsocli.providers import Providers
+from mabledsocli.secrets import SecretProvider
+from mabledsocli.stages import Stages
+from mabledsocli.constants import *
+from mabledsocli.dict_utils import set_dict_value
+from mabledsocli.contexts import Contexts
+from mabledsocli.aws_utils import *
 
 
 _default_spec = {
@@ -70,10 +70,11 @@ class AwsSsmSecretProvider(SecretProvider):
 
 ###--------------------------------------------------------------------------------------------
 
-    def list(self, project, application, stage, uninherited, decrypt):
+    def list(self, project, application, stage, uninherited=False, decrypt=False, filter=None):
         secrets = load_context_ssm_parameters(project, application, stage, ['SecureString'], prefix=self.get_prefix(), uninherited=uninherited, decrypt=decrypt)
         result = {'Secrets': []}
         for key, details in secrets.items():
+            if filter and not re.match(filter, key): continue
             result['Secrets'].append({
                                 'Key': key, 
                                 'Value': details['Value'], 
