@@ -1,15 +1,15 @@
 import re
 import boto3
-from dsocli.exceptions import DSOException
-from dsocli.logger import Logger
-from dsocli.config import Configs
-from dsocli.providers import Providers
-from dsocli.templates import TemplateProvider
-from dsocli.stages import Stages
-from dsocli.constants import *
-from dsocli.dict_utils import set_dict_value
-from dsocli.contexts import Contexts
-from dsocli.aws_utils import *
+from mabledsocli.exceptions import DSOException
+from mabledsocli.logger import Logger
+from mabledsocli.config import Configs
+from mabledsocli.providers import Providers
+from mabledsocli.templates import TemplateProvider
+from mabledsocli.stages import Stages
+from mabledsocli.constants import *
+from mabledsocli.dict_utils import set_dict_value
+from mabledsocli.contexts import Contexts
+from mabledsocli.aws_utils import *
 
 
 _default_spec = {
@@ -51,10 +51,11 @@ class AwsSsmTemplateProvider(TemplateProvider):
 
 ###--------------------------------------------------------------------------------------------
 
-    def list(self, project, application, stage, uninherited):
+    def list(self, project, application, stage, uninherited=False, filter=None):
         templates = load_context_ssm_parameters(project, application, stage, ['StringList'], prefix=self.get_prefix(), uninherited=uninherited)
         result = {'Templates': []}
         for key, details in templates.items():
+            if filter and not re.match(filter, key): continue
             result['Templates'].append({
                                     'Key': key, 
                                     # 'Contents': details['Value'], 
