@@ -5,13 +5,13 @@ import json
 import glob
 from pathlib import Path
 import jinja2
-from dsocli.logger import Logger
-from dsocli.config import Configs
-from dsocli.providers import Providers
-from dsocli.templates import Templates, TemplateProvider
-from dsocli.stages import Stages
-from dsocli.constants import *
-from dsocli.exceptions import DSOException
+from mabledsocli.logger import Logger
+from mabledsocli.config import Configs
+from mabledsocli.providers import Providers
+from mabledsocli.templates import Templates, TemplateProvider
+from mabledsocli.stages import Stages
+from mabledsocli.constants import *
+from mabledsocli.exceptions import DSOException
 
 
 _settings = {
@@ -36,12 +36,6 @@ class LocalTemplateProvider(TemplateProvider):
     def templates_root_path(self):
         return f"{Configs.working_dir}/{_settings['templates_dir']}"
 
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
-
-    def get_key_validator(self):
-        return r"^[a-zA-Z0-9_-]+(/[a-zA-Z0-9_-]+)*(.[a-zA-Z0-9_-]+)?$"
-
 ###--------------------------------------------------------------------------------------------
 
     def add(self, project, application, key, content):
@@ -63,39 +57,66 @@ class LocalTemplateProvider(TemplateProvider):
         templatesKeys = env.list_templates()
         result = []
         for key in templatesKeys:
-            result.append({'Key': key, 'Path': os.path.join(_settings['templates_dir'], key)})
+            result.append({
+                'Key': key, 
+                'Path': os.path.join(_settings['templates_dir'], key),
+                })
         return {'Templates': result}
 
 ###--------------------------------------------------------------------------------------------
 
-    def get(self,  project, application, key):
+    def get(self,  project, application, key, revision=None):
         path = f"{self.templates_root_path}/{key}"
         if not os.path.exists(path):
-            raise DSOException(CLI_MESSAGES['TemplateNotFound'].format(key))
+            raise DSOException(f"Template '{key}' not found in the given context: project={project}, application={application}")
         Logger.debug(f"Getting template: path={path}")
         with open(path, 'r', encoding='utf-8') as f:
             result = f.read()
-        return result
+        return {
+                'Key': key, 
+                'Path': os.path.join(_settings['templates_dir'], key),
+                'Contents': result
+                }
+
+# ###--------------------------------------------------------------------------------------------
+
+#     def delete(self, project, application, key, recursive=False):
+#         result = []
+
+#         path = f"{self.templates_root_path}/{key}"
+#         path = re.sub('^./', '', path)
+
+#         for item in glob.glob(path, recursive=recursive):
+#             if not Path(item).is_file(): continue
+#             Logger.debug(f"Deleting template: path={str(item)}")
+#             os.remove(str(item))
+#             key = str(item)[len(re.sub('^./', '', self.templates_root_path))+1:]
+#             result.append({
+#                     'Key': key, 
+#                     'Path': os.path.join(_settings['templates_dir'], key)
+#                     })
+#         if not len(result):
+#             raise DSOException(f"Template '{key}' not found in the given context: project={project}, application={application}")
+#         return result
 
 ###--------------------------------------------------------------------------------------------
 
-    def delete(self, project, application, key, recursive=False):
-        result = []
-
+    def delete(self, project, application, key):
         path = f"{self.templates_root_path}/{key}"
-        path = re.sub('^./', '', path)
-
-        for item in glob.glob(path, recursive=recursive):
-            if not Path(item).is_file(): continue
-            Logger.debug(f"Deleting template: path={str(item)}")
-            os.remove(str(item))
-            key = str(item)[len(re.sub('^./', '', self.templates_root_path))+1:]
-            result.append({'Key': key, 'Path': os.path.join(_settings['templates_dir'], key)})
-        if not len(result):
-            raise DSOException(f"No template found matching '{key}'.")
-        return result
+        if not os.path.exists(path) or os.path.isdir(path):
+            raise DSOException(f"Template '{key}' not found in the given context: project={project}, application={application}")
+        Logger.debug(f"Deleting template: path={key}")
+        os.remove(path)
+        return {
+                'Key': key, 
+                'Path': path,
+                }
 
 ###--------------------------------------------------------------------------------------------
+
+    def history(self, project, application, key):
+        raise DSOException('The template provider does not support versioning.')
+
 ###--------------------------------------------------------------------------------------------
 ###--------------------------------------------------------------------------------------------
 
